import 'dart:async';

import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'package:smart_page/src/controller/control_app_view_provider.dart';
import 'package:smart_page/src/view/widgets/floating_alert_widget.dart';
import 'package:smart_page/src/view/widgets/loading_widget.dart';

class MainCreatePage extends StatefulWidget {
  final Widget page;
  final bool showLoadingMark;
  final Widget? bottomAppbar;
  final AppBar? appBar;
  final FloatingActionButton? floatingActionButton;
  final FloatingActionButtonLocation? floatingActionButtonLocation;

  const MainCreatePage({
    Key? key,
    required this.page,
    this.showLoadingMark = false,
    this.bottomAppbar,
    this.appBar,
    this.floatingActionButton,
    this.floatingActionButtonLocation,
  }) : super(key: key);

  @override
  State<MainCreatePage> createState() => _MainCreatePageState();
}

class _MainCreatePageState extends State<MainCreatePage> {
  late StreamSubscription<ConnectivityResult> connectivitySubscription;

  @override
  initState() {
    super.initState();
    WidgetsFlutterBinding.ensureInitialized();
    WidgetsBinding.instance.addPostFrameCallback((_) {
      checkConnctivityForIntiaalize();
      connectivitySubscription = Connectivity().onConnectivityChanged.listen(
        (ConnectivityResult result) {
          if (result == ConnectivityResult.none) {
            debugPrint("set the disconnect to true");
            context.read<ControlAppViewProvider>().hendelDisConnected(true);
          } else {
            debugPrint("set the disconnect to false");
            context.read<ControlAppViewProvider>().hendelDisConnected(false);
          }
        },
      );
    });
  }

  checkConnctivityForIntiaalize() {
    Connectivity().checkConnectivity().then(
      (ConnectivityResult connectivityResult) {
        if (connectivityResult == ConnectivityResult.none) {
          context.read<ControlAppViewProvider>().hendelDisConnected(true);
          debugPrint("set the disconnect to true second");
        } else {
          context.read<ControlAppViewProvider>().hendelDisConnected(false);
          debugPrint("set the disconnect to false second");
        }
      },
    );
  }

  @override
  dispose() {
    connectivitySubscription.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: widget.appBar,
      floatingActionButtonLocation: widget.floatingActionButtonLocation ??
          FloatingActionButtonLocation.centerDocked,
      floatingActionButton: widget.floatingActionButton,
      bottomNavigationBar: widget.bottomAppbar,
      body: SafeArea(
        child: Stack(
          children: [
            widget.page,
            if (context.watch<ControlAppViewProvider>().showLoadingScreen)
              const LoadingWidget(),
            if (widget.showLoadingMark)
              const FloatingAlertWidget(
                text: "Please Check Your Connection",
                icon: Icons.wifi_off_rounded,
              ),
          ],
        ),
      ),
    );
  }
}
